@@ -1,5 +1,3 @@
-import json
-
 from algora.api.service.datasets.model import DatasetSearchRequest, DatasetRequest
 
 
@@ -18,21 +16,21 @@ def _get_datasets_request_info() -> dict:
 def _search_datasets_request_info(request: DatasetSearchRequest) -> dict:
     return {
         "endpoint": f"config/datasets/dataset/search",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
 
 
 def _create_dataset_request_info(request: DatasetRequest) -> dict:
     return {
         "endpoint": f"config/datasets/dataset",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
 
 
 def _update_dataset_request_info(id: str, request: DatasetRequest) -> dict:
     return {
         "endpoint": f"config/datasets/dataset/{id}",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
 
 
