@@ -1,5 +1,3 @@
-import json
-
 from algora.api.service.datasets.field_group.model import FieldGroupRequest
 
 
@@ -18,14 +16,14 @@ def _get_field_groups_request_info() -> dict:
 def _create_field_group_request_info(request: FieldGroupRequest) -> dict:
     return {
         "endpoint": f"config/datasets/field-group",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
 
 
 def _update_field_group_request_info(id: str, request: FieldGroupRequest) -> dict:
     return {
         "endpoint": f"config/datasets/field-group/{id}",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
 
 
