@@ -26,14 +26,14 @@ def _get_schema_fields_request_info(id: str) -> dict:
 def _create_schema_request_info(request: SchemaRequest) -> dict:
     return {
         "endpoint": f"config/datasets/schema",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
 
 
 def _update_schema_request_info(id: str, request: SchemaRequest) -> dict:
     return {
         "endpoint": f"config/datasets/schema/{id}",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
 
 
